# invoke with "--with tests" to enable tests, currently disabled
# as we need to package both wsgi_intercept and pytest-localserver
# for them to work. Will also need BR: pystest once the two
# above packages exit in Fedora

%bcond_with tests

Name:       vdirsyncer
Version:    0.8.1
Release:    1%{?git_tag}%{?dist}
Summary:    Synchronize calendars and contacts

License:    MIT
URL:        https://github.com/untitaker/%{name}
Source0:    https://pypi.python.org/packages/source/v/%{name}/%{name}-%{version}.tar.gz
Patch0:     vdirsyncer-0.6.0-no-scm.patch

BuildArch:  noarch

BuildRequires:  python-atomicwrites
BuildRequires:  python-click
BuildRequires:  python-click-log
BuildRequires:  python-click-threading
BuildRequires:  python-devel
BuildRequires:  python-icalendar
BuildRequires:  python-lxml
BuildRequires:  python-requests
BuildRequires:  python-setuptools
BuildRequires:  python-sphinx
BuildRequires:  python-sphinx_rtd_theme

Requires:       python-atomicwrites
Requires:       python-click >= 5.1
Requires:       python-click-log
Requires:       python-click-threading
Requires:       python-icalendar
Requires:       python-lxml >= 3.0
Requires:       python-requests
Requires:       python-requests-toolbelt >= 0.5.0

%description
vdirsyncer synchronizes your calendars and address books between two entities.
The supported protocols are CalDAV, CardDAV, arbitrary HTTP resources and some
more.

It aims to be for CalDAV and CardDAV what OfflineIMAP is for IMAP.

%package doc
Summary:        Documentation for vdirsyncer

%description doc
The vdirsyncer-doc package provides all the documentation
for the vdirsyncer calendar/address-book synchronization utility.

%prep
%setup -q
%patch0 -p1 -b .no-scm

%build
%{__python2} setup.py build
# Custom sphinx docs need to import vdirsyncer classes from the untarred
# source tree
export PYTHONPATH=`pwd`
cd docs
# NOT using smp_mflags because sphinx cannot really cope with it
# i.e. one out of 20 builds will misteriously fail
make SPHINXBUILD=sphinx-build man html text
cd ..
unset PYTHONPATH
# Remove extra copy of text docs
rm -vrf docs/_build/html/_sources
rm -fv docs/_build/html/{.buildinfo,objects.inv}

%install
%{__python2} setup.py --quiet install -O1 --skip-build --root $RPM_BUILD_ROOT
install -d "$RPM_BUILD_ROOT%{_mandir}/man1"
cp -r docs/_build/man/%{name}.1 "$RPM_BUILD_ROOT%{_mandir}/man1"

%check
%if %{with tests}
sh build.sh tests
%endif


%files
%license LICENSE
%doc AUTHORS.rst README.rst CONTRIBUTING.rst
%{python2_sitelib}/*
%{_bindir}/vdirsyncer
%{_mandir}/man1/%{name}.1.*

# Still one rpmlint warning due to BZ 1107813
# W: wrong-file-end-of-line-encoding /usr/share/doc/vdirsyncer-doc/html/_static/jquery.js
%files doc
%doc docs/_build/html docs/_build/text

%changelog
* Fri Feb 12 2016 Michele Baldessari <michele@acksyn.org> - 0.8.1-1
- New upstream (requires python-click-{log,threading})

* Fri Feb 05 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.6.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sun Jan 24 2016 Michele Baldessari <michele@acksyn.org> - 0.7.5-1
- New upstream, requires 0.5.0 python-requests-toolbelt

* Sat Nov 28 2015 Michele Baldessari <michele@acksyn.org> - 0.7.3-1
- New upstream (BZ 1275860)

* Sun Sep 13 2015 Michele Baldessari <michele@acksyn.org> - 0.6.0-2
- Add python-atomicwrites requires (BZ 1262597)

* Thu Aug 06 2015 Ben Boeckel <mathstuf@gmail.com> - 0.6.0-1
- Update to 0.6.0
- Use %%license
- Use PyPI tarball (see setup.py)

* Mon Jul 06 2015 Michele Baldessari <michele@acksyn.org> - 0.5.2-2
- Fix FTBFS (BZ#1046338)
* Tue Jun 16 2015 Michele Baldessari <michele@acksyn.org> - 0.5.2-1
- Update to 0.5.2
- Drop doc build patch
* Wed Jun 03 2015 Michele Baldessari <michele@acksyn.org> - 0.5.1-1
- Update to 0.5.1
- Drop system-urllib3.patch

* Fri Mar 13 2015 Michele Baldessari <michele@acksyn.org> - 0.4.4-1
- Update to 0.4.4

* Mon Mar 02 2015 Michele Baldessari <michele@redhat.com> - 0.4.3-5
- Disable python3 for now until khal supports it

* Sun Mar 01 2015 Michele Baldessari <michele@redhat.com> - 0.4.3-4
- Port to python3

* Sun Mar 01 2015 Michele Baldessari <michele@redhat.com> - 0.4.3-3
- Split out a -doc subpackage as fedora-review complained

* Sat Feb 28 2015 Michele Baldessari <michele@redhat.com> - 0.4.3-2
- Conditional test builds

* Mon Feb 23 2015 Michele Baldessari <michele@redhat.com> - 0.4.3-1
- New upstream

* Wed Feb 11 2015 Michele Baldessari <michele@redhat.com> - 0.4.2-3
- Add html and text documentation

* Wed Feb 04 2015 Michele Baldessari <michele@redhat.com> - 0.4.2-2
- Add python-atomicwrites dependency

* Tue Feb 03 2015 Michele Baldessari <michele@redhat.com> - 0.4.2-1
- New upstream

* Mon Jan 05 2015 Michele Baldessari <michele@redhat.com> - 0.4.0-2
- Force use of system urllib3

* Mon Jan 05 2015 Michele Baldessari <michele@redhat.com> - 0.4.0-1
- New upstream

* Mon Jan 05 2015 Michele Baldessari <michele@redhat.com> - 0.3.4-2
- Added python-icalendar and python-click Requires

* Mon Dec 15 2014 Michele Baldessari <michele@redhat.com> - 0.3.4-1
- New upstream

* Wed Oct 01 2014 Michele Baldessari <michele@redhat.com> - 0.3.0-1
- Initial packaging
